/**
 * Storages and registers all gulp classes and their tasks.
 */
var MetadataStorage = (function () {
    function MetadataStorage() {
        // -------------------------------------------------------------------------
        // Properties
        // -------------------------------------------------------------------------
        this.gulpclassMetadatas = [];
        this.taskMetadatas = [];
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    MetadataStorage.prototype.addGulpclassMetadata = function (metadata) {
        var _this = this;
        this.gulpclassMetadatas.push(metadata);
        this.taskMetadatas
            .filter(function (taskMetadata) { return taskMetadata.classConstructor === metadata.classConstructor; })
            .forEach(function (taskMetadata) { return _this.registerTasks(metadata, taskMetadata); });
    };
    MetadataStorage.prototype.addTaskMetadata = function (metadata) {
        this.taskMetadatas.push(metadata);
        var gulpclassMetadata = this.gulpclassMetadatas.reduce(function (found, m) {
            return m.classConstructor === metadata.classConstructor ? m : found;
        }, undefined);
        if (gulpclassMetadata)
            this.registerTasks(gulpclassMetadata, metadata);
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    MetadataStorage.prototype.registerTasks = function (gulpclassMetadata, taskMetadata) {
        var _this = this;
        if (!gulpclassMetadata.classInstance)
            gulpclassMetadata.classInstance = new gulpclassMetadata.classConstructor();
        gulpclassMetadata.gulpInstance.task(taskMetadata.name, function (cb) {
            var methodResult = gulpclassMetadata.classInstance[taskMetadata.method](cb);
            if (taskMetadata.isSequence && methodResult instanceof Array) {
                return require('run-sequence').apply(_this, methodResult.concat(cb));
            }
            else if (taskMetadata.isSequence && methodResult instanceof Array) {
                return require('merge2').apply(_this);
            }
            else {
                return methodResult;
            }
        });
    };
    return MetadataStorage;
})();
exports.MetadataStorage = MetadataStorage;
/**
 * Default metadata storage is used as singleton and can be used to storage all metadatas.
 */
exports.defaultMetadataStorage = new MetadataStorage();
//# sourceMappingURL=MetadataStorage.js.map